@@ -21,9 +21,9 @@
 #ifndef __KGAME_H_
 #define __KGAME_H_
 
-#include <QtCore/QDataStream>
-#include <QtCore/QString>
-#include <QtCore/QList>
+#include <QDataStream>
+#include <QString>
+#include <QList>
 #include <QLoggingCategory>
 
 #include "kgamenetwork.h"
@@ -42,7 +42,7 @@ class KGamePrivate;
 
 /**
  * \class KGame kgame.h <KGame/KGame>
- * 
+ *
  * @short The main KDE game object
  *
  * The KGame class is the central game object. A game basically
@@ -102,17 +102,17 @@ public:
      * game in load/save and network operations. Change this between
      * games.
      */
-    explicit KGame(int cookie=42,QObject* parent=0);
+    explicit KGame(int cookie=42,QObject* parent=nullptr);
 
     /**
     * Destructs the game
     */
-    virtual ~KGame();
+    ~KGame() override;
 
     /**
      * Gives debug output of the game status
      */
-    virtual void Debug();
+    void Debug() override;
 
     /**
      * Game status - Use this to Control the game flow.
@@ -409,7 +409,7 @@ public:
 
     /**
     * This function allows to find the pointer to a player
-    * property when you know it's id
+    * property when you know its id
     */
     KGamePropertyBase* findProperty(int id) const;
 
@@ -460,7 +460,7 @@ public:
      * @param sender
      * @param clientID the client from which we received the transmission - hardly used
      **/
-    virtual void networkTransmission(QDataStream &stream, int msgid, quint32 receiver, quint32 sender, quint32 clientID);
+    void networkTransmission(QDataStream &stream, int msgid, quint32 receiver, quint32 sender, quint32 clientID) override;
 
     /**
      * Returns a pointer to the KGame property handler
@@ -532,7 +532,7 @@ Q_SIGNALS:
      * the data which is NOT a game or player property.
      * It is not necessary to use this signal for a full property game.
      *
-     * This signal is emitted <em>before</em> the players are loaded by 
+     * This signal is emitted <em>before</em> the players are loaded by
      * KGame. See also signalLoad
      *
      * You must load <em>exactly</em> the same data from the stream that you have saved
@@ -557,7 +557,7 @@ Q_SIGNALS:
      * which is NOT a game or player property.
      * It is not necessary to use this signal for a full property game.
      *
-     * This signal is emitted <em>before</em> the players are saved by 
+     * This signal is emitted <em>before</em> the players are saved by
      * KGame. See also signalSave
      *
      * If you can choose between signalSavePrePlayers and signalSave then
@@ -566,7 +566,7 @@ Q_SIGNALS:
      * @param stream the save stream
      **/
     void signalSavePrePlayers(QDataStream &stream);
-    
+
     /**
      * The game will be saved to the given stream. Fill this with data
      * which is NOT a game or player property.
@@ -577,7 +577,7 @@ Q_SIGNALS:
     void signalSave(QDataStream &stream);
 
     /**
-     * Is emmited if a game with a different version cookie is loaded.
+     * Is emitted if a game with a different version cookie is loaded.
      * Normally this should result in an error. But maybe you do support
      * loading of older game versions. Here would be a good place to do a
      * conversion.
@@ -592,7 +592,7 @@ Q_SIGNALS:
     /**
      * We got an user defined update message. This is usually done
      * by a sendData in a inherited KGame Object which defines its
-     * own methods and has to syncronise them over the network.
+     * own methods and has to synchronize them over the network.
      * Reaction to this is usually a call to a KGame function.
      */
     void signalNetworkData(int msgid,const QByteArray& buffer, quint32 receiver, quint32 sender);
@@ -625,7 +625,7 @@ Q_SIGNALS:
 
 
     /**
-    * This signal is emmited if a player property changes its value and
+    * This signal is emitted if a player property changes its value and
     * the property is set to notify this change
     */
     void signalPropertyChanged(KGamePropertyBase *property, KGame *me);
@@ -641,7 +641,7 @@ Q_SIGNALS:
     void signalGameOver(int status, KPlayer *current, KGame *me);
 
     /**
-    * Is emmited after a client is successfully connected to the game.
+    * Is emitted after a client is successfully connected to the game.
     * The client id is the id of the new game client. An easy way to
     * check whether that's us is
     * \code
@@ -692,7 +692,7 @@ protected:
      * {
      *   qint32 move;
      *   msg >>  move;
-     *   kDebug() << "  Player" << player->id() << "moved to" << move;
+     *   qDebug() << "  Player" << player->id() << "moved to" << move;
      *   return true;
      * }
      * \endcode
@@ -728,7 +728,7 @@ protected:
     * each game to make sense.
     *
     * Not overwriting this function will activate a default behaviour which
-    * will deactivate players until the @ref maxPlayers() numebr is reached
+    * will deactivate players until the @ref maxPlayers() number is reached
     * according to the KPlayer::networkPriority() value. Players with a low
     * value will be kicked out first. With equal priority players of the new
     * client will leave first. This means, not setting this value and not
@@ -843,7 +843,7 @@ protected:
     virtual void negotiateNetworkGame(quint32 clientID);
 
     /**
-     * syncronise the random numbers with all network clients
+     * synchronize the random numbers with all network clients
      * not used by KGame - if it should be kept then as public method
      */
     void syncRandom();
@@ -861,10 +861,10 @@ protected:
     virtual int checkGameOver(KPlayer *player);
 
     /**
-     * Load a saved game, from file OR network. Internal. 
+     * Load a saved game, from file OR network. Internal.
      * Warning: loadgame must not rely that all players all already
      * activated. Actually the network will activate a player AFTER
-     * the loadgame only. This is not true anymore. But be careful 
+     * the loadgame only. This is not true anymore. But be careful
      * anyway.
      *
      * @param stream a data stream where you can stream the game from
@@ -876,7 +876,7 @@ protected:
     virtual bool loadgame(QDataStream &stream, bool network, bool reset);
 
     /**
-     * Save a game, to file OR network. Internal. 
+     * Save a game, to file OR network. Internal.
      *
      * @param stream a data stream where you can stream the game from
      * @param network is it a call from the network or from a file (unused but informative)
